@@ -96,7 +96,7 @@ def start_python_console(namespace=None, noipython=False, banner=''):
 
 
 
-def main(return_results=True):
+def main(return_results=False):
     """Runs the GoogleScraper application as determined by the various configuration points.
 
     The main() function encompasses the core functionality of GoogleScraper. But it
@@ -124,8 +124,23 @@ def main(return_results=True):
     proxy_file = Config['GLOBAL'].get('proxy_file', '')
     proxy_db = Config['GLOBAL'].get('mysql_proxy_db', '')
 
+    if Config['GLOBAL'].getboolean('shell', False):
+        namespace = {}
+        namespace['session'] = get_session(scoped=False, create=False)
+        namespace['ScraperSearch'] = ScraperSearch
+        namespace['SERP'] = SERP
+        namespace['Link'] = Link
+        print('Available objects:')
+        print('session - A sqlalchemy session of the results database')
+        print('ScraperSearch - Search/Scrape job instances')
+        print('SERP - A search engine results page')
+        print('Link - A single link belonging to a SERP')
+        start_python_console(namespace)
+        return
+
     if not (keyword or keywords) and not kwfile:
-        raise InvalidConfigurationException('No keywords to scrape for. Please provide either an keyword file (Option: --keyword-file) or specify and keyword with --keyword.')
+        logger.error('No keywords to scrape for. Please provide either an keyword file (Option: --keyword-file) or specify and keyword with --keyword.')
+        return
 
     if Config['GLOBAL'].getboolean('fix_cache_names'):
         fix_broken_cache_names()
@@ -166,27 +181,13 @@ def main(return_results=True):
         if proxies:
             logger.info('The following proxies are used: {}'.format('\t\t\n'.join([proxy.host + ':' + proxy.port for proxy in proxies])))
 
-        if Config['SCRAPING'].get('scrapemethod') == 'sel':
+        if Config['SCRAPING'].get('scrapemethod') == 'selenium':
             mode = 'selenium mode with {} browser instances'.format(Config['SELENIUM'].getint('num_browser_instances'))
         else:
             mode = 'http mode'
         logger.info('By using scrapemethod: {}'.format(mode))
         return
 
-    if Config['GLOBAL'].getboolean('shell', False):
-        namespace = {}
-        namespace['session'] = get_session(scoped=False, create=False)
-        namespace['ScraperSearch'] = ScraperSearch
-        namespace['SERP'] = SERP
-        namespace['Link'] = Link
-        print('Available objects:')
-        print('session - A sqlalchemy session of the results database')
-        print('ScraperSearch - Search/Scrape job instances')
-        print('SERP - A search engine results page')
-        print('Link - A single link belonging to a SERP')
-        start_python_console(namespace)
-        return
-
     # get a scoped sqlalchemy session
     session = get_session(scoped=False, create=True)
 
@@ -222,7 +223,7 @@ def main(return_results=True):
     cache_lock = threading.Lock()
 
     # Let the games begin
-    if Config['SCRAPING'].get('scrapemethod', 'http') == 'sel':
+    if Config['SCRAPING'].get('scrapemethod', 'http') == 'selenium':
         # A lock to prevent multiple threads from solving captcha.
         lock = threading.Lock()
 
