@@ -60,18 +60,26 @@ def get_proxies(host, user, password, database, port=3306, unix_socket=None):
         port: The mysql port, by default 3306
         unix_socket: Sometimes you need to specify the mysql socket file when mysql doesn't reside
                      in a standard location.
+
+    Returns;
+        A list of proxies obtained from the database
+
+    Raisese:
+        An Exception when connecting to the database fails.
     """
     try:
         conn = pymysql.connect(host=host, port=port, user=user, passwd=password, unix_socket=unix_socket)
         conn.select_db(database)
         cur = conn.cursor(pymysql.cursors.DictCursor)
-        # Adapt this code to make it retrieving the proxies in the right format.
+        # Adapt this code for you to make it retrieving the proxies in the right format.
         cur.execute('SELECT host, port, username, password, protocol FROM proxies')
-        proxies = [Proxy(proto=s['protocol'], host=s['host'], port=s['port'], username=s['username'], password=s['password']) for s in cur.fetchall()]
+        proxies = [Proxy(proto=s['protocol'], host=s['host'], port=s['port'],
+                         username=s['username'], password=s['password']) for s in cur.fetchall()]
 
         return proxies
     except Exception as e:
         logger.error(e)
+        raise
 
 def get_proxies_from_mysql_db(s):
     """Give this function a mysql connection string like this
@@ -82,4 +90,5 @@ def get_proxies_from_mysql_db(s):
     """
     pattern = re.compile(r'(?P<dbms>\w*?)://(?P<user>\w*?):(?P<pwd>.*?)@(?P<host>\w*?)/(?P<db>\w*)')
     found = pattern.search(s)
-    return get_proxies(found.group('host'), found.group('user'), found.group('pwd'), found.group('db'))
+    return get_proxies(found.group('host'), found.group('user'),
+                                found.group('pwd'), found.group('db'))
